@@ -64,6 +64,7 @@ cff_write <- function(x,
                       keys = list(),
                       cff_version = "1.2.0",
                       gh_keywords = TRUE,
+                      dependencies = TRUE,
                       validate = TRUE,
                       verbose = TRUE) {
   # On missing use package root
@@ -72,7 +73,8 @@ cff_write <- function(x,
   citat <- cff_create(x,
     keys = keys,
     cff_version = cff_version,
-    gh_keywords = gh_keywords
+    gh_keywords = gh_keywords,
+    dependencies = dependencies
   )
 
 
