@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ---- include = FALSE-------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
@@ -6,13 +6,14 @@ knitr::opts_chunk$set(
 
 library(cffr)
 
-## ----summary , echo=FALSE-----------------------------------------------------
+## ----summary , echo=FALSE---------------------------------
 
 keys <- cff_schema_keys(sorted = TRUE)
 origin <- vector(length = length(keys))
 origin[keys == "cff-version"] <- "parameter on function"
 origin[keys == "type"] <- "Fixed value: 'software'"
 origin[keys == "identifiers"] <- "DESCRIPTION/CITATION files"
+origin[keys == "references"] <- "DESCRIPTION/CITATION files"
 
 origin[keys %in% c(
   "message",
@@ -31,22 +32,21 @@ origin[keys %in% c(
 
 origin[keys %in% c(
   "doi",
-  "preferred-citation",
-  "references"
+  "preferred-citation"
 )] <- "CITATION file"
 
 
 origin[origin == FALSE] <- "Not parsed by cffr"
 
 df <- data.frame(
-  key = paste0("<a href='#", keys, "'>", keys, "</strong>"),
+  key = paste0("<a href='#", keys, "'>", keys, "</a>"),
   source = origin
 )
 
 
 knitr::kable(df, escape = FALSE)
 
-## ----abstract-----------------------------------------------------------------
+## ----abstract---------------------------------------------
 
 library(cffr)
 
@@ -62,7 +62,7 @@ cat(cff_obj$abstract)
 
 cat(pkg$get("Description"))
 
-## ----authors------------------------------------------------------------------
+## ----authors----------------------------------------------
 
 cff_obj <- cff_create("rmarkdown")
 pkg <- desc::desc(file.path(find.package("rmarkdown"), "DESCRIPTION"))
@@ -75,13 +75,13 @@ authors[vapply(authors, function(x) {
   "aut" %in% x$role || "cre" %in% x$role
 }, logical(1))]
 
-## ----cffversion---------------------------------------------------------------
+## ----cffversion-------------------------------------------
 
 cff_objv110 <- cff_create("jsonlite", cff_version = "v1.1.0")
 
 cat(cff_objv110$`cff-version`)
 
-## ----contact------------------------------------------------------------------
+## ----contact----------------------------------------------
 
 cff_obj <- cff_create("rmarkdown")
 pkg <- desc::desc(file.path(find.package("rmarkdown"), "DESCRIPTION"))
@@ -90,7 +90,7 @@ cff_obj$contact
 
 pkg$get_author()
 
-## ----date-released------------------------------------------------------------
+## ----date-released----------------------------------------
 
 # From an installed package
 
@@ -127,7 +127,7 @@ desc::desc_set("Date", "1999-01-01", file = tmp)
 
 cat(cff_create(tmp)$`date-released`)
 
-## ----doi----------------------------------------------------------------------
+## ----doi--------------------------------------------------
 
 cff_doi <- cff_create("cffr")
 
@@ -135,7 +135,7 @@ cat(cff_doi$doi)
 
 cat(cff_doi$`preferred-citation`$doi)
 
-## ----identifiers--------------------------------------------------------------
+## ----identifiers------------------------------------------
 file <- system.file("examples/DESCRIPTION_many_urls", package = "cffr")
 
 pkg <- desc::desc(file)
@@ -148,7 +148,7 @@ cat(cff_create(file)$`repository-code`)
 
 cff_create(file)$identifiers
 
-## ----keyword------------------------------------------------------------------
+## ----keyword----------------------------------------------
 
 # A DESCRIPTION file without keywords
 nokeywords <- system.file("examples/DESCRIPTION_basic", package = "cffr")
@@ -172,7 +172,7 @@ desc::desc_set("X-schema.org-keywords", "keyword1, keyword2, keyword3", file = t
 
 cat(cff_create(tmp2)$keywords)
 
-## ----ghkeyword----------------------------------------------------------------
+## ----ghkeyword--------------------------------------------
 
 # Get cff object from jsonvalidate
 
@@ -188,7 +188,7 @@ jsonval$keywords
 # The repo
 jsonval$`repository-code`
 
-## ----license------------------------------------------------------------------
+## ----license----------------------------------------------
 
 cff_obj <- cff_create("yaml")
 
@@ -198,18 +198,18 @@ pkg <- desc::desc(file.path(find.package("yaml"), "DESCRIPTION"))
 
 cat(pkg$get("License"))
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------
 #  msg <- paste0(
 #    'To cite package "',
 #    "NAME_OF_THE_PACKAGE",
 #    '" in publications use:'
 #  )
 
-## ----message------------------------------------------------------------------
+## ----message----------------------------------------------
 
 cat(cff_create("jsonlite")$message)
 
-## ----preferred-citation-------------------------------------------------------
+## ----preferred-citation-----------------------------------
 
 cffobj <- cff_create("rmarkdown")
 
@@ -217,7 +217,7 @@ cffobj$`preferred-citation`
 
 citation("rmarkdown")[1]
 
-## ----references---------------------------------------------------------------
+## ----references-------------------------------------------
 
 cffobj <- cff_create("rmarkdown")
 
@@ -225,7 +225,7 @@ cffobj$references
 
 citation("rmarkdown")[-1]
 
-## ----repository---------------------------------------------------------------
+## ----repository-------------------------------------------
 
 # Installed package
 
@@ -289,7 +289,7 @@ cat(cff_create(tmp)[["repository"]])
 options(orig_options)
 getOption("repos")
 
-## ----repository-code----------------------------------------------------------
+## ----repository-code--------------------------------------
 
 # Installed package on GitHub
 
@@ -308,20 +308,20 @@ cat(cff_create(gitlab)$`repository-code`)
 
 desc::desc(gitlab)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-------------------------------------------
 #  title <- paste0(
 #    "NAME_OF_THE_PACKAGE",
 #    ": ",
 #    "TITLE_OF_THE_PACKAGE"
 #  )
 
-## ----title--------------------------------------------------------------------
+## ----title------------------------------------------------
 
 # Installed package
 
 cat(cff_create("testthat")$title)
 
-## ----url----------------------------------------------------------------------
+## ----url--------------------------------------------------
 
 # Many urls
 manyurls <- system.file("examples/DESCRIPTION_many_urls", package = "cffr")
@@ -332,7 +332,7 @@ cat(cff_create(manyurls)$url)
 
 desc::desc(manyurls)
 
-## ----version------------------------------------------------------------------
+## ----version----------------------------------------------
 
 # Should be (>= 3.0.0)
 cat(cff_create("testthat")$version)
